Module schema

Module schema 

Structs

FieldDef
A named, typed field definition for building Arrow schemas.

Enums

WpDataType
WPL data types that can be mapped to Apache Arrow types.

Functions

parse_wp_type
Parses a WPL type string into a WpDataType.
to_arrow_field
Converts a FieldDef into an Arrow ArrowField.
to_arrow_schema
Converts a slice of FieldDef into an Arrow Schema.
to_arrow_type
Maps a WpDataType to the corresponding ArrowDataType.